@@ -29,6 +29,8 @@ from octobot.api.backtesting import (
     get_independent_backtesting_exchange_manager_ids,
     get_independent_backtesting_bot_id,
     log_independent_backtesting_report,
+    get_independent_backtesting_config,
+    get_independent_backtesting_symbols_by_exchanges,
     initialize_and_run_independent_backtesting,
     join_independent_backtesting,
     initialize_independent_backtesting_config,
@@ -43,6 +45,7 @@ from octobot.api.strategy_optimizer import (
     initialize_design_strategy_optimizer,
     update_strategy_optimizer_total_runs,
     generate_and_save_strategy_optimizer_runs,
+    create_strategy_optimizer_settings,
     resume_design_strategy_optimizer,
     cancel_strategy_optimizer,
     print_optimizer_report,
@@ -78,6 +81,8 @@ __all__ = [
     "get_independent_backtesting_exchange_manager_ids",
     "get_independent_backtesting_bot_id",
     "log_independent_backtesting_report",
+    "get_independent_backtesting_config",
+    "get_independent_backtesting_symbols_by_exchanges",
     "initialize_and_run_independent_backtesting",
     "join_independent_backtesting",
     "initialize_independent_backtesting_config",
@@ -90,6 +95,7 @@ __all__ = [
     "initialize_design_strategy_optimizer",
     "update_strategy_optimizer_total_runs",
     "generate_and_save_strategy_optimizer_runs",
+    "create_strategy_optimizer_settings",
     "resume_design_strategy_optimizer",
     "cancel_strategy_optimizer",
     "print_optimizer_report",
